@@ -13,16 +13,18 @@
 # limitations under the License.
 # ==============================================================================
 """Chex assertion utilities."""
+
 import collections
 import collections.abc
 import functools
 import inspect
 import itertools
 import traceback
-from typing import Any, Sequence, Type, Union, Callable, Optional, Set
+from typing import List, Sequence, Type, Union, Callable, Optional, Set
 import unittest
 from unittest import mock
 
+from chex._src import asserts_internal as ai
 from chex._src import pytypes
 import jax
 import jax.numpy as jnp
@@ -34,92 +36,21 @@ Scalar = pytypes.Scalar
 Array = pytypes.Array
 ArrayTree = pytypes.ArrayTree
 
-# Custom pytypes.
-TLeaf = Any
-TLeavesEqCmpFn = Callable[[TLeaf, TLeaf], bool]
-TLeavesEqCmpErrorFn = Callable[[TLeaf, TLeaf], str]
+# Private symbols.
+_ERR_PREFIX = ai.ERR_PREFIX
+_TRACE_COUNTER = ai.TRACE_COUNTER
 
+_TLeaf = ai.TLeaf
+_TLeavesEqCmpFn = ai.TLeavesEqCmpFn
+_TLeavesEqCmpErrorFn = ai.TLeavesEqCmpErrorFn
+_ShapeMatcher = ai.TShapeMatcher
 
-def _format_tree_path(path: Sequence[Any]) -> str:
-  return "/".join(str(p) for p in path)
-
-
-def _num_devices_available(devtype: str, backend: Optional[str] = None) -> int:
-  """Returns the number of available device of the given type."""
-  devtype = devtype.lower()
-  supported_types = ("cpu", "gpu", "tpu")
-  if devtype not in supported_types:
-    raise ValueError(
-        f"Unknown device type '{devtype}' (expected one of {supported_types}).")
-
-  return sum(d.platform == devtype for d in jax.devices(backend))
-
-
-def _is_traceable(fn):
-  """Checks if function is traceable.
-
-  JAX traces a function when it is wrapped with @jit, @pmap, or @vmap.
-  In other words, this function checks whether `fn` is wrapped with any of
-  the aforementioned JAX transformations.
-
-  Args:
-    fn: function to assert.
-
-  Returns:
-    Bool indicating whether fn is traceable.
-  """
-
-  tokens = (
-      "_python_jit.",  # PyJIT  in Python ver. < 3.7
-      "_cpp_jit.",  # CppJIT in Python ver. < 3.7 (deprecated)
-      ".reraise_with_filtered_traceback",  # JIT    in Python ver. >= 3.7
-      "CompiledFunction",  # C++ JIT in jaxlib 0.1.66 or newer.
-      "pmap.",  # pmap
-      "vmap.",  # vmap
-  )
-
-  # Un-wrap `fn` and check if any internal f-n is jitted by pattern matching.
-  fn_ = fn
-  while True:
-    if any(t in str(fn_) for t in tokens):
-      return True
-
-    if hasattr(fn_, "__wrapped__"):
-      # Wrapper.
-      fn_globals = getattr(fn_, "__globals__", {})
-
-      if fn_globals.get("__name__", None) == "jax.api":
-        # Wrapper from `jax.api`.
-        return True
-
-      if "api_boundary" in fn_globals:
-        # api_boundary is a JAX wrapper for traced functions.
-        return True
-
-      try:
-        if isinstance(fn_, jax.lib.xla_extension.jax_jit.CompiledFunction):
-          return True
-      except AttributeError:
-        pass
-    else:
-      break
-
-    fn_ = fn_.__wrapped__
-  return False
-
-
-def _assert_leaves_all_eq_comparator(
-    equality_comparator: TLeavesEqCmpFn,
-    error_msg_fn: Callable[[TLeaf, TLeaf, str, int, int],
-                           str], path: Sequence[Any], *leaves: Sequence[TLeaf]):
-  """Asserts all leaves are equal using custom comparator."""
-  path_str = _format_tree_path(path)
-  for i in range(1, len(leaves)):
-    if not equality_comparator(leaves[0], leaves[i]):
-      raise AssertionError(error_msg_fn(leaves[0], leaves[i], path_str, 0, i))
-
-
-_TRACE_COUNTER = collections.Counter()
+_assert_leaves_all_eq_comparator = ai.assert_leaves_all_eq_comparator
+_chex_assertion = ai.chex_assertion
+_format_shape_matcher = ai.format_shape_matcher
+_format_tree_path = ai.format_tree_path
+_is_traceable = ai.is_traceable
+_num_devices_available = ai.num_devices_available
 
 
 def clear_trace_counter():
@@ -198,7 +129,7 @@ def assert_max_traces(fn=None, n=None):
     _TRACE_COUNTER[fn_hash] += int(has_tracers_in_args)
     if _TRACE_COUNTER[fn_hash] > n:
       raise AssertionError(
-          f"Function '{fn.__name__}' is traced > {n} times!\n"
+          f"{_ERR_PREFIX}Function '{fn.__name__}' is traced > {n} times!\n"
           "It often happens when a jitted function is defined inside another "
           "function that is called multiple times (i.e. the jitted f-n is a "
           "new object every time). Make sure that your code does not exploit "
@@ -212,6 +143,7 @@ def assert_max_traces(fn=None, n=None):
   return fn_wrapped
 
 
+@_chex_assertion
 def assert_scalar(x: Scalar):
   """Checks argument is a scalar, as defined in pytypes.py (int or float)."""
   if not isinstance(x, (int, float)):
@@ -219,8 +151,10 @@ def assert_scalar(x: Scalar):
         "The argument must be a scalar, was {}".format(type(x)))
 
 
+@_chex_assertion
 def assert_scalar_in(
     x: Scalar, min_: Scalar, max_: Scalar, included: bool = True):
+  """Checks argument is a scalar within segment (by default)."""
   assert_scalar(x)
   if included:
     if not min_ <= x <= max_:
@@ -232,6 +166,7 @@ def assert_scalar_in(
           "The argument must be in ({}, {}), was {}".format(min_, max_, x))
 
 
+@_chex_assertion
 def assert_scalar_positive(x: Scalar):
   """Checks that the scalar is strictly positive."""
   assert_scalar(x)
@@ -239,6 +174,7 @@ def assert_scalar_positive(x: Scalar):
     raise AssertionError("The argument must be positive, was {}".format(x))
 
 
+@_chex_assertion
 def assert_scalar_non_negative(x: Scalar):
   """Checks that the scalar is non negative."""
   assert_scalar(x)
@@ -246,6 +182,7 @@ def assert_scalar_non_negative(x: Scalar):
     raise AssertionError("The argument must be non negative, was {}".format(x))
 
 
+@_chex_assertion
 def assert_scalar_negative(x: Scalar):
   """Checks that the scalar is non negative."""
   assert_scalar(x)
@@ -253,6 +190,7 @@ def assert_scalar_negative(x: Scalar):
     raise AssertionError("The argument must be negative, was {}".format(x))
 
 
+@_chex_assertion
 def assert_equal_shape(inputs: Sequence[Array]):
   """Checks that all arrays have the same shape.
 
@@ -270,6 +208,7 @@ def assert_equal_shape(inputs: Sequence[Array]):
       raise AssertionError(f"Arrays have different shapes: {shapes}.")
 
 
+@_chex_assertion
 def assert_equal_shape_prefix(inputs, prefix_len):
   """Check that the leading `prefix_dims` dims of all inputs have same shape.
 
@@ -287,6 +226,7 @@ def assert_equal_shape_prefix(inputs, prefix_len):
     raise AssertionError(f"Arrays have different shape prefixes: {shapes}")
 
 
+@_chex_assertion
 def assert_equal_shape_suffix(inputs, suffix_len):
   """Check that the final `suffix_len` dims of all inputs have same shape.
 
@@ -304,19 +244,79 @@ def assert_equal_shape_suffix(inputs, suffix_len):
     raise AssertionError(f"Arrays have different shape suffixes: {shapes}")
 
 
+def _unelided_shape_matches(
+    actual_shape: Sequence[int],
+    expected_shape: Sequence[Optional[Union[int, Set[int]]]]) -> bool:
+  """Returns True if `actual_shape` is compatible with `expected_shape`."""
+  if len(actual_shape) != len(expected_shape):
+    return False
+  for actual, expected in zip(actual_shape, expected_shape):
+    if expected is None:
+      continue
+    if isinstance(expected, set):
+      if actual not in expected:
+        return False
+    elif actual != expected:
+      return False
+  return True
+
+
+def _shape_matches(actual_shape: Sequence[int],
+                   expected_shape: _ShapeMatcher) -> bool:
+  """Returns True if `actual_shape` is compatible with `expected_shape`."""
+  # Splits `expected_shape` based on the position of the ellipsis, if present.
+  expected_prefix: List[Union[int, Set[int]]] = []
+  expected_suffix: Optional[List[Union[int, Set[int]]]] = None
+  for dim in expected_shape:
+    if dim is Ellipsis:
+      if expected_suffix is not None:
+        raise ValueError(
+            "`expected_shape` may not contain more than one ellipsis, "
+            f"but got {_format_shape_matcher(expected_shape)}")
+      expected_suffix = []
+    elif expected_suffix is None:
+      expected_prefix.append(dim)
+    else:
+      expected_suffix.append(dim)
+
+  # If there is no ellipsis, just compare to the full `actual_shape`.
+  if expected_suffix is None:
+    assert len(expected_prefix) == len(expected_shape)
+    return _unelided_shape_matches(actual_shape, expected_prefix)
+
+  # Checks that the actual rank is least the number of non-elided dimensions.
+  if len(actual_shape) < len(expected_prefix) + len(expected_suffix):
+    return False
+
+  if expected_prefix:
+    actual_prefix = actual_shape[:len(expected_prefix)]
+    if not _unelided_shape_matches(actual_prefix, expected_prefix):
+      return False
+
+  if expected_suffix:
+    actual_suffix = actual_shape[-len(expected_suffix):]
+    if not _unelided_shape_matches(actual_suffix, expected_suffix):
+      return False
+
+  return True
+
+
+@_chex_assertion
 def assert_shape(inputs: Union[Scalar, Union[Array, Sequence[Array]]],
-                 expected_shapes: Union[Sequence[Optional[int]],
-                                        Sequence[Sequence[Optional[int]]]]):
+                 expected_shapes: Union[_ShapeMatcher,
+                                        Sequence[_ShapeMatcher]]):
   """Checks that the shape of all inputs matches specified expected_shapes.
 
   Valid usages include:
 
   ```
-    assert_shape(x, ())                    # x is scalar
-    assert_shape(x, (2, 3))                # x has shape (2, 3)
-    assert_shape(x, (2, None))             # x has rank 2 and `x.shape[0] == 2`
-    assert_shape([x, y], ())               # x and y are scalar
-    assert_shape([x, y], [(), (2,3)])      # x is scalar and y has shape (2, 3)
+    assert_shape(x, ())                  # x is scalar
+    assert_shape(x, (2, 3))              # x has shape (2, 3)
+    assert_shape(x, (2, {1, 3}))         # x has shape (2, 1) or (2, 3)
+    assert_shape(x, (2, None))           # x has rank 2 and `x.shape[0] == 2`
+    assert_shape(x, (2, ...))            # x has rank >= 1 and `x.shape[0] == 2`
+    assert_shape([x, y], ())             # x and y are scalar
+    assert_shape([x, y], [(), (2,3)])    # x is scalar and y has shape (2, 3)
   ```
 
   Args:
@@ -351,10 +351,8 @@ def assert_shape(inputs: Union[Scalar, Union[Array, Sequence[Array]]],
   errors = []
   for idx, (x, expected) in enumerate(zip(inputs, expected_shapes)):
     shape = getattr(x, "shape", ())  # scalars have shape () by definition.
-    if not (
-        len(shape) == len(expected)
-        and all(j is None or i == j for i, j in zip(shape, expected))):
-      errors.append((idx, shape, expected))
+    if not _shape_matches(shape, expected):
+      errors.append((idx, shape, _format_shape_matcher(expected)))
 
   if errors:
     msg = "; ".join(
@@ -362,6 +360,7 @@ def assert_shape(inputs: Union[Scalar, Union[Array, Sequence[Array]]],
     raise AssertionError("Error in shape compatibility check: " + msg + ".")
 
 
+@_chex_assertion
 def assert_is_broadcastable(shape_a: Sequence[int], shape_b: Sequence[int]):
   """Checks that an array of `shape_a` is broadcastable to one of `shape_b`.
 
@@ -384,6 +383,7 @@ def assert_is_broadcastable(shape_a: Sequence[int], shape_b: Sequence[int]):
         raise error
 
 
+@_chex_assertion
 def assert_equal_rank(inputs: Sequence[Array]):
   """Checks that all arrays have the same rank.
 
@@ -401,6 +401,7 @@ def assert_equal_rank(inputs: Sequence[Array]):
       raise AssertionError(f"Arrays have different rank: {ranks}.")
 
 
+@_chex_assertion
 def assert_rank(
     inputs: Union[Scalar, Union[Array, Sequence[Array]]],
     expected_ranks: Union[int, Set[int], Sequence[Union[int, Set[int]]]]):
@@ -474,6 +475,7 @@ def assert_rank(
     raise AssertionError("Error in rank compatibility check: " + msg + ".")
 
 
+@_chex_assertion
 def assert_type(
     inputs: Union[Scalar, Union[Array, Sequence[Array]]],
     expected_types: Union[Type[Scalar], Sequence[Type[Scalar]]]):
@@ -534,6 +536,7 @@ def assert_type(
     raise AssertionError("Error in type compatibility check: " + msg + ".")
 
 
+@_chex_assertion
 def assert_axis_dimension(tensor: Array, axis: int, expected: int):
   """Assert dimension of a specific axis of a tensor.
 
@@ -557,6 +560,7 @@ def assert_axis_dimension(tensor: Array, axis: int, expected: int):
         " but got {} instead.".format(expected, axis, tensor.shape[axis]))
 
 
+@_chex_assertion
 def assert_axis_dimension_gt(tensor: Array, axis: int, val: int):
   """Assert dimension of a specific axis of a tensor.
 
@@ -579,6 +583,7 @@ def assert_axis_dimension_gt(tensor: Array, axis: int, val: int):
         f" '{axis}' but got '{tensor.shape[axis]}' instead.")
 
 
+@_chex_assertion
 def assert_numerical_grads(
     f: Callable[..., Array],
     f_args: Sequence[Array],
@@ -608,6 +613,7 @@ def assert_numerical_grads(
     jax_test.check_grads(f, f_args, order=order, atol=atol, **check_kwargs)
 
 
+@_chex_assertion
 def assert_tree_no_nones(tree: ArrayTree):
   """Asserts tree does not contain `None`s.
 
@@ -625,6 +631,7 @@ def assert_tree_no_nones(tree: ArrayTree):
   dm_tree.map_structure_with_path(_assert_fn, tree)
 
 
+@_chex_assertion
 def assert_tree_shape_prefix(tree: ArrayTree,
                              shape_prefix: Sequence[int],
                              *,
@@ -655,17 +662,23 @@ def assert_tree_shape_prefix(tree: ArrayTree,
   dm_tree.map_structure_with_path(_assert_fn, tree)
 
 
-def assert_tree_all_equal_structs(*trees: Sequence[ArrayTree]):
+@_chex_assertion
+def assert_trees_all_equal_structs(*trees: ArrayTree):
   """Asserts trees have the same structure.
 
   Note that `None`s are treated as PyTree nodes.
 
   Args:
-    *trees: trees which structures to assert on equality.
+    *trees: >= 2 trees to assert equal structure between.
 
   Raise:
     AssertionError: if structures of any two trees are different.
   """
+  if len(trees) < 2:
+    raise ValueError(
+        "assert_trees_all_equal_structs on a single tree does not make sense. "
+        "Maybe you wrote `assert_trees_all_equal_structs([a, b])` instead of "
+        "`assert_trees_all_equal_structs(a, b)` ?")
   first_treedef = jax.tree_structure(trees[0])
   other_treedefs = (jax.tree_structure(t) for t in trees[1:])
   for i, treedef in enumerate(other_treedefs, start=1):
@@ -676,10 +689,17 @@ def assert_tree_all_equal_structs(*trees: Sequence[ArrayTree]):
           f"\n tree {i}: {treedef}")
 
 
-def assert_tree_all_equal_comparator(equality_comparator: TLeavesEqCmpFn,
-                                     error_msg_fn: TLeavesEqCmpErrorFn,
-                                     *trees: Sequence[ArrayTree],
-                                     ignore_nones: bool = False):
+assert_tree_all_equal_structs = ai.deprecation_wrapper(
+    assert_trees_all_equal_structs,
+    old_name="assert_tree_all_equal_structs",
+    new_name="assert_trees_all_equal_structs")
+
+
+@_chex_assertion
+def assert_trees_all_equal_comparator(equality_comparator: _TLeavesEqCmpFn,
+                                      error_msg_fn: _TLeavesEqCmpErrorFn,
+                                      *trees: ArrayTree,
+                                      ignore_nones: bool = False):
   """Asserts all trees are equal as per the custom comparator for leaves.
 
   Args:
@@ -687,25 +707,34 @@ def assert_tree_all_equal_comparator(equality_comparator: TLeavesEqCmpFn,
                          whether they are equal. Expected to be transitive.
     error_msg_fn: a function accepting two unequal as per `equality_comparator`
                   leaves and returning an error message.
-    *trees: trees to check on equality as per `equality_comparator`.
+    *trees: at least 2 trees to check on equality as per `equality_comparator`.
     ignore_nones: whether to ignore `None`s in the trees.
 
   Raises:
+    ValueError: if *trees does not have at least two elements.
     AssertionError: if `equality_comparator` returns False on any pair of trees.
   """
-  if len(trees) < 2: return
-  assert_tree_all_equal_structs(*trees)
+  if len(trees) < 2:
+    raise ValueError(
+        "Assertions over only one tree does not make sense. Maybe you wrote "
+        "`assert_trees_xxx([a, b])` instead of `assert_trees_xxx(a, b)`, or "
+        "forgot the `error_msg_fn` arg to `assert_trees_all_equal_comparator`?")
+  assert_trees_all_equal_structs(*trees)
   if not ignore_nones: assert_tree_no_nones(trees)
 
-  def tree_error_msg_fn(l_1: TLeaf, l_2: TLeaf, path: str, i_1: int, i_2: int):
+  def tree_error_msg_fn(l_1: _TLeaf, l_2: _TLeaf, path: str, i_1: int,
+                        i_2: int):
     msg = error_msg_fn(l_1, l_2)
-    return f"Trees {i_1} and {i_2} differ in leaves '{path}': {msg}."
+    if path:
+      return f"Trees {i_1} and {i_2} differ in leaves '{path}': {msg}."
+    else:
+      return f"Trees (arrays) {i_1} and {i_2} differ: {msg}."
 
   def wrapped_equality_comparator(leaf_1, leaf_2):
     if leaf_1 is None or leaf_1 is None:
       # Either both or none of leaves can be `None`s.
       assert leaf_1 is None and leaf_2 is None, (
-          "non-mutual cases must be caught by assert_tree_all_equal_structs")
+          "non-mutual cases must be caught by assert_trees_all_equal_structs")
       if ignore_nones:
         return True
 
@@ -716,17 +745,24 @@ def assert_tree_all_equal_comparator(equality_comparator: TLeavesEqCmpFn,
   dm_tree.map_structure_with_path(cmp, *trees)
 
 
-def assert_tree_all_close(*trees: Sequence[ArrayTree],
-                          rtol: float = 1e-07,
-                          atol: float = .0,
-                          ignore_nones: bool = False):
+assert_tree_all_equal_comparator = ai.deprecation_wrapper(
+    assert_trees_all_equal_comparator,
+    old_name="assert_tree_all_equal_comparator",
+    new_name="assert_trees_all_equal_comparator")
+
+
+@_chex_assertion
+def assert_trees_all_close(*trees: ArrayTree,
+                           rtol: float = 1e-07,
+                           atol: float = .0,
+                           ignore_nones: bool = False):
   """Asserts trees have leaves with approximately equal values.
 
   This compares the difference between values of actual and desired to
    atol + rtol * abs(desired).
 
   Args:
-    *trees: a sequence of trees with array leaves.
+    *trees: a sequence of >= 2 trees with array leaves.
     rtol: relative tolerance.
     atol: absolute tolerance.
     ignore_nones: whether to ignore `None`s in the trees.
@@ -739,21 +775,36 @@ def assert_tree_all_close(*trees: Sequence[ArrayTree],
       np.testing.assert_allclose, rtol=rtol, atol=atol,
       err_msg="Error in value equality check: Values not approximately equal")
 
-  def cmp_fn(arr_1, arr_2):
-    assert_fn(arr_1, arr_2)  # Raises an AssertionError if values are not close.
+  def cmp_fn(arr_1, arr_2) -> bool:
+    try:
+      # Raises an AssertionError if values are not close.
+      assert_fn(arr_1, arr_2)
+    except AssertionError:
+      return False
     return True
 
-  dummy_err_msg_fn = lambda arr_1, arr_2: None
-  assert_tree_all_equal_comparator(
-      cmp_fn, dummy_err_msg_fn, *trees, ignore_nones=ignore_nones)
+  def err_msg_fn(arr_1, arr_2) -> str:
+    try:
+      assert_fn(arr_1, arr_2)
+    except AssertionError as e:
+      return str(e)
+    return ""
+
+  assert_trees_all_equal_comparator(
+      cmp_fn, err_msg_fn, *trees, ignore_nones=ignore_nones)
+
+assert_tree_all_close = ai.deprecation_wrapper(
+    assert_trees_all_close,
+    old_name="assert_tree_all_close",
+    new_name="assert_trees_all_close")
 
 
-def assert_tree_all_equal_shapes(*trees: Sequence[ArrayTree],
-                                 ignore_nones: bool = False):
+def assert_trees_all_equal_shapes(*trees: ArrayTree,
+                                  ignore_nones: bool = False):
   """Asserts trees have the same structure and leaves' shapes.
 
   Args:
-    *trees: a sequence of trees with array leaves.
+    *trees: a sequence of >= 2 trees with array leaves.
     ignore_nones: whether to ignore `None`s in the trees.
 
   Raises:
@@ -762,10 +813,17 @@ def assert_tree_all_equal_shapes(*trees: Sequence[ArrayTree],
   """
   cmp_fn = lambda arr_1, arr_2: arr_1.shape == arr_2.shape
   err_msg_fn = lambda arr_1, arr_2: f"shapes: {arr_1.shape} != {arr_2.shape}"
-  assert_tree_all_equal_comparator(
+  assert_trees_all_equal_comparator(
       cmp_fn, err_msg_fn, *trees, ignore_nones=ignore_nones)
 
 
+assert_tree_all_equal_shapes = ai.deprecation_wrapper(
+    assert_trees_all_equal_shapes,
+    old_name="assert_tree_all_equal_shapes",
+    new_name="assert_trees_all_equal_shapes")
+
+
+@_chex_assertion
 def assert_devices_available(
     n: int,
     devtype: str,
@@ -793,6 +851,7 @@ def assert_devices_available(
     raise AssertionError(f"No {n} {devtype.upper()}s available in {devs}.")
 
 
+@_chex_assertion
 def assert_tpu_available(backend: Optional[str] = None):
   """Checks that at least one TPU device is available.
 
@@ -806,6 +865,7 @@ def assert_tpu_available(backend: Optional[str] = None):
     raise AssertionError(f"No TPU devices available in {jax.devices(backend)}.")
 
 
+@_chex_assertion
 def assert_gpu_available(backend: Optional[str] = None):
   """Checks that at least one GPU device is available.
 
@@ -819,6 +879,7 @@ def assert_gpu_available(backend: Optional[str] = None):
     raise AssertionError(f"No GPU devices available in {jax.devices(backend)}.")
 
 
+@_chex_assertion
 def assert_tree_all_finite(tree_like: ArrayTree):
   """Assert all tensor leaves in a tree are finite.
 
@@ -836,11 +897,12 @@ def assert_tree_all_finite(tree_like: ArrayTree):
     raise AssertionError(f"Tree contains non-finite value: {error_msg}.")
 
 
+@_chex_assertion
 def assert_equal(first, second):
   """Assert the two objects are equal as determined by the '==' operator.
 
   Arrays with more than one element cannot be compared.
-  Use `assert_tree_all_close` to compare arrays.
+  Use `assert_trees_all_close` to compare arrays.
 
   Args:
     first: first object.
@@ -853,6 +915,7 @@ def assert_equal(first, second):
   testcase.assertEqual(first, second)
 
 
+@_chex_assertion
 def assert_not_both_none(x, y):
   """Assert that at least one of the arguments is not `None`."""
   if x is None and y is None:
@@ -860,6 +923,7 @@ def assert_not_both_none(x, y):
         "At least one of the arguments must be different from `None`")
 
 
+@_chex_assertion
 def assert_exactly_one_is_none(x, y):
   """Assert that one and only one of the arguments is `None`."""
   if (x is None) == (y is None):
@@ -875,6 +939,7 @@ def if_args_not_none(fn, *args, **kwargs):
     fn(*args, **kwargs)
 
 
+@_chex_assertion
 def assert_is_divisible(numerator: int, denominator: int):
   """Assert that the numerator is divisible exactly by the denominator."""
   if numerator % denominator != 0:
