@@ -19,54 +19,27 @@ import functools
 from absl.testing import absltest
 from absl.testing import parameterized
 from chex._src import asserts
+from chex._src import asserts_internal
 from chex._src import variants
 import jax
 import jax.numpy as jnp
 import numpy as np
 
+_get_err_regex = asserts_internal.get_err_regex
+
 
 def as_arrays(arrays):
   return [np.asarray(a) for a in arrays]
 
 
+def array_from_shape(*shape):
+  return np.ones(shape=shape)
+
+
 def emplace(arrays):
   return arrays
 
 
-class IsTraceableTest(variants.TestCase):
-
-  @variants.variants(with_jit=True, with_pmap=True)
-  @parameterized.named_parameters(
-      ('CPP_JIT', True),
-      ('PY_JIT', False),
-  )
-  def test_is_traceable(self, cpp_jit):
-    prev_state = jax.api.FLAGS.experimental_cpp_jit
-    jax.api.FLAGS.experimental_cpp_jit = cpp_jit
-
-    def dummy_wrapper(fn):
-
-      @functools.wraps(fn)
-      def fn_wrapped(fn, *args):
-        return fn(args)
-
-      return fn_wrapped
-
-    fn = lambda x: x.sum()
-    wrapped_fn = dummy_wrapper(fn)
-    self.assertFalse(asserts._is_traceable(fn))
-    self.assertFalse(asserts._is_traceable(wrapped_fn))
-
-    var_fn = self.variant(fn)
-    wrapped_var_f = dummy_wrapper(var_fn)
-    var_wrapped_f = self.variant(wrapped_fn)
-    self.assertTrue(asserts._is_traceable(var_fn))
-    self.assertTrue(asserts._is_traceable(wrapped_var_f))
-    self.assertTrue(asserts._is_traceable(var_wrapped_f))
-
-    jax.api.FLAGS.experimental_cpp_jit = prev_state
-
-
 class AssertMaxTracesTest(variants.TestCase):
 
   def setUp(self):
@@ -159,7 +132,8 @@ class AssertMaxTracesTest(variants.TestCase):
       self.assertEqual(fn('a', 'b'), 'ab')
 
     # (max_traces + 1)-th re-tracing.
-    with self.assertRaisesRegex(AssertionError, 'fn.* is traced > .* times!'):
+    with self.assertRaisesRegex(AssertionError,
+                                _get_err_regex('fn.* is traced > .* times!')):
       arg = jnp.zeros(max_traces + 1)
       fn_jitted(arg, 2)
 
@@ -206,14 +180,15 @@ class AssertMaxTracesTest(variants.TestCase):
     self.assertEqual(outer_fn(3), 6)
 
     # Fails since the traced inner function is redefined at each call.
-    with self.assertRaisesRegex(AssertionError, 'fn.* is traced > .* times!'):
+    with self.assertRaisesRegex(AssertionError,
+                                _get_err_regex('fn.* is traced > .* times!')):
       outer_fn(4)
 
     asserts.clear_trace_counter()
     for i in range(10):
       if i > 2:
-        with self.assertRaisesRegex(AssertionError,
-                                    'fn.* is traced > .* times!'):
+        with self.assertRaisesRegex(
+            AssertionError, _get_err_regex('fn.* is traced > .* times!')):
           outer_fn(1)
       else:
         outer_fn(1)
@@ -240,37 +215,45 @@ class ScalarAssertTest(parameterized.TestCase):
   def test_scalar(self):
     asserts.assert_scalar(1)
     asserts.assert_scalar(1.)
-    with self.assertRaisesRegex(AssertionError, 'must be a scalar'):
+    with self.assertRaisesRegex(AssertionError,
+                                _get_err_regex('must be a scalar')):
       asserts.assert_scalar(np.array(1.))  # pytype: disable=wrong-arg-types
 
   def test_scalar_positive(self):
     asserts.assert_scalar_positive(0.5)
-    with self.assertRaisesRegex(AssertionError, 'must be positive'):
+    with self.assertRaisesRegex(AssertionError,
+                                _get_err_regex('must be positive')):
       asserts.assert_scalar_positive(-0.5)
 
   def test_scalar_non_negative(self):
     asserts.assert_scalar_non_negative(0.5)
     asserts.assert_scalar_non_negative(0.)
-    with self.assertRaisesRegex(AssertionError, 'must be non negative'):
+    with self.assertRaisesRegex(AssertionError,
+                                _get_err_regex('must be non negative')):
       asserts.assert_scalar_non_negative(-0.5)
 
   def test_scalar_negative(self):
     asserts.assert_scalar_negative(-0.5)
-    with self.assertRaisesRegex(AssertionError, 'argument must be negative'):
+    with self.assertRaisesRegex(AssertionError,
+                                _get_err_regex('argument must be negative')):
       asserts.assert_scalar_negative(0.5)
 
   def test_scalar_in(self):
     asserts.assert_scalar_in(0.5, 0, 1)
-    with self.assertRaisesRegex(AssertionError, 'argument must be in'):
+    with self.assertRaisesRegex(AssertionError,
+                                _get_err_regex('argument must be in')):
       asserts.assert_scalar_in(-0.5, 0, 1)
-    with self.assertRaisesRegex(AssertionError, 'argument must be in'):
+    with self.assertRaisesRegex(AssertionError,
+                                _get_err_regex('argument must be in')):
       asserts.assert_scalar_in(1.5, 0, 1)
 
   def test_scalar_in_excluded(self):
     asserts.assert_scalar_in(0.5, 0, 1, included=False)
-    with self.assertRaisesRegex(AssertionError, 'argument must be in'):
+    with self.assertRaisesRegex(AssertionError,
+                                _get_err_regex('argument must be in')):
       asserts.assert_scalar_in(0, 0, 1, included=False)
-    with self.assertRaisesRegex(AssertionError, 'argument must be in'):
+    with self.assertRaisesRegex(AssertionError,
+                                _get_err_regex('argument must be in')):
       asserts.assert_scalar_in(1, 0, 1, included=False)
 
 
@@ -283,7 +266,8 @@ class EqualShapeAssertTest(parameterized.TestCase):
   )
   def test_equal_shape_should_fail(self, arrays):
     arrays = as_arrays(arrays)
-    with self.assertRaisesRegex(AssertionError, 'Arrays have different shapes'):
+    with self.assertRaisesRegex(AssertionError,
+                                _get_err_regex('Arrays have different shapes')):
       asserts.assert_equal_shape(arrays)
 
   @parameterized.named_parameters(
@@ -309,7 +293,8 @@ class EqualShapeAssertTest(parameterized.TestCase):
   )
   def test_equal_shape_prefix_should_fail(self, arrays):
     arrays = as_arrays(arrays)
-    with self.assertRaisesRegex(AssertionError, 'different shape prefixes'):
+    with self.assertRaisesRegex(AssertionError,
+                                _get_err_regex('different shape prefixes')):
       asserts.assert_equal_shape_prefix(arrays, prefix_len=1)
 
 
@@ -321,11 +306,13 @@ class ShapeAssertTest(parameterized.TestCase):
       ('some_wrong_shape', [[1, 2], [3, 4]], [(1, 2), (1, 3)]),
       ('wrong_common_shape', [[1, 2], [3, 4, 3]], (2,)),
       ('wrong_common_shape_2', [[1, 2, 3], [1, 2]], (2,)),
+      ('some_wrong_shape_set', [[1, 2], [3, 4]], [(1, 2), (1, {3, 4})]),
   )
   def test_shape_should_fail(self, arrays, shapes):
     arrays = as_arrays(arrays)
-    with self.assertRaisesRegex(AssertionError,
-                                'input .+ has shape .+ but expected .+'):
+    with self.assertRaisesRegex(
+        AssertionError,
+        _get_err_regex('input .+ has shape .+ but expected .+')):
       asserts.assert_shape(arrays, shapes)
 
   @parameterized.named_parameters(
@@ -335,7 +322,8 @@ class ShapeAssertTest(parameterized.TestCase):
   def test_shape_should_fail_wrong_length(self, arrays, shapes):
     arrays = as_arrays(arrays)
     with self.assertRaisesRegex(
-        AssertionError, 'Length of `inputs` and `expected_shapes` must match'):
+        AssertionError,
+        _get_err_regex('Length of `inputs` and `expected_shapes` must match')):
       asserts.assert_shape(arrays, shapes)
 
   @parameterized.named_parameters(
@@ -345,7 +333,7 @@ class ShapeAssertTest(parameterized.TestCase):
       ('matrices_variable_shape', [[[1, 2], [3, 4]]], (None, 2)),
       ('vectors_common_shape', [[1, 2], [3, 4]], (2,)),
       ('variable_common_shape', [[[1, 2], [3, 4]], [[1], [3]]], (2, None)),
-
+      ('common_shape_set', [[[1, 2], [3, 4]], [[1], [3]]], (2, {1, 2})),
   )
   def test_shape_should_pass(self, arrays, shapes):
     arrays = as_arrays(arrays)
@@ -354,6 +342,46 @@ class ShapeAssertTest(parameterized.TestCase):
   def test_pytypes_pass(self):
     arrays = as_arrays([[[1, 2], [3, 4]], [[1], [3]]])
     asserts.assert_shape(arrays, (2, None))
+    asserts.assert_shape(arrays, (2, {1, 2}))
+    asserts.assert_shape(arrays, (2, ...))
+
+  @parameterized.named_parameters(
+      ('prefix_2', array_from_shape(2, 3, 4, 5, 6), (..., 4, 5, 6)),
+      ('prefix_1', array_from_shape(3, 4, 5, 6), (..., 4, 5, 6)),
+      ('prefix_0', array_from_shape(4, 5, 6), (..., 4, 5, 6)),
+      ('inner_2', array_from_shape(2, 3, 4, 5, 6), (2, 3, ..., 6)),
+      ('inner_1', array_from_shape(2, 3, 4, 6), (2, 3, ..., 6)),
+      ('inner_0', array_from_shape(2, 3, 6), (2, 3, ..., 6)),
+      ('suffix_2', array_from_shape(2, 3, 4, 5, 6), (2, 3, 4, ...)),
+      ('suffix_1', array_from_shape(2, 3, 4, 5), (2, 3, 4, ...)),
+      ('suffix_0', array_from_shape(2, 3, 4), (2, 3, 4, ...)),
+  )
+  def test_ellipsis_should_pass(self, array, expected_shape):
+    asserts.assert_shape(array, expected_shape)
+
+  @parameterized.named_parameters(
+      ('prefix', array_from_shape(3, 1, 5), (..., 4, 5, 6)),
+      ('inner_bad_prefix', array_from_shape(2, 1, 4, 6), (2, 3, ..., 6)),
+      ('inner_bad_suffix', array_from_shape(2, 3, 1, 5), (2, 3, ..., 6)),
+      ('inner_both_bad', array_from_shape(2, 1, 4, 5), (2, 3, ..., 6)),
+      ('suffix', array_from_shape(2, 3, 1, 5), (2, 3, 4, ...)),
+      ('short_rank_prefix', array_from_shape(2, 3), (..., 4, 5, 6)),
+      ('short_rank_inner', array_from_shape(2, 3), (2, 3, ..., 6)),
+      ('short_rank_suffix', array_from_shape(2, 3), (2, 3, 4, ...)),
+  )
+  def test_ellipsis_should_fail(self, array, expected_shape):
+    with self.assertRaisesRegex(
+        AssertionError,
+        _get_err_regex('input .+ has shape .+ but expected .+')):
+      asserts.assert_shape(array, expected_shape)
+
+  @parameterized.named_parameters(
+      ('prefix_and_suffix', array_from_shape(2, 3), (..., 2, 3, ...)),)
+  def test_multiple_ellipses(self, array, expected_shape):
+    with self.assertRaisesRegex(  # pylint: disable=g-error-prone-assert-raises
+        ValueError,
+        '`expected_shape` may not contain more than one ellipsis, but got .+'):
+      asserts.assert_shape(array, expected_shape)
 
 
 def rank_array(n):
@@ -412,8 +440,8 @@ class RankAssertTest(parameterized.TestCase):
   )
   def test_rank_should_fail_single(self, array, rank):
     array = np.asarray(array)
-    with self.assertRaisesRegex(AssertionError,
-                                'input .+ has rank .+ but expected .+'):
+    with self.assertRaisesRegex(
+        AssertionError, _get_err_regex('input .+ has rank .+ but expected .+')):
       asserts.assert_rank(array, rank)
 
   @parameterized.named_parameters(
@@ -424,8 +452,8 @@ class RankAssertTest(parameterized.TestCase):
   )
   def test_assert_rank_should_fail_sequence(self, arrays, ranks):
     arrays = as_arrays(arrays)
-    with self.assertRaisesRegex(AssertionError,
-                                'input .+ has rank .+ but expected .+'):
+    with self.assertRaisesRegex(
+        AssertionError, _get_err_regex('input .+ has rank .+ but expected .+')):
       asserts.assert_rank(arrays, ranks)
 
   @parameterized.named_parameters(
@@ -435,7 +463,8 @@ class RankAssertTest(parameterized.TestCase):
   def test_rank_should_fail_wrong_length(self, array, rank):
     array = np.asarray(array)
     with self.assertRaisesRegex(
-        AssertionError, 'Length of inputs and expected_ranks must match.'):
+        AssertionError,
+        _get_err_regex('Length of inputs and expected_ranks must match.')):
       asserts.assert_rank(array, rank)
 
   @parameterized.named_parameters(
@@ -479,8 +508,8 @@ class TypeAssertTest(parameterized.TestCase):
       ('one_int_as_bool', 3, bool),
   )
   def test_type_should_fail_scalar(self, scalars, wrong_type):
-    with self.assertRaisesRegex(AssertionError,
-                                'input .+ has type .+ but expected .+'):
+    with self.assertRaisesRegex(
+        AssertionError, _get_err_regex('input .+ has type .+ but expected .+')):
       asserts.assert_type(scalars, wrong_type)
 
   @variants.variants(with_device=True, without_device=True)
@@ -490,8 +519,8 @@ class TypeAssertTest(parameterized.TestCase):
   )
   def test_type_should_fail_array(self, array, wrong_type):
     array = self.variant(emplace)(array)
-    with self.assertRaisesRegex(AssertionError,
-                                'input .+ has type .+ but expected .+'):
+    with self.assertRaisesRegex(
+        AssertionError, _get_err_regex('input .+ has type .+ but expected .+')):
       asserts.assert_type(array, wrong_type)
 
   @parameterized.named_parameters(
@@ -518,8 +547,8 @@ class TypeAssertTest(parameterized.TestCase):
     an_int = 2
     a_np_float = np.asarray([3., 4.])
     a_jax_int = jnp.asarray([5, 6])
-    with self.assertRaisesRegex(AssertionError,
-                                'input .+ has type .+ but expected .+'):
+    with self.assertRaisesRegex(
+        AssertionError, _get_err_regex('input .+ has type .+ but expected .+')):
       asserts.assert_type([a_float, an_int, a_np_float, a_jax_int],
                           [float, int, float, float])
 
@@ -537,7 +566,8 @@ class TypeAssertTest(parameterized.TestCase):
   )
   def test_type_should_fail_wrong_length(self, array, wrong_type):
     with self.assertRaisesRegex(
-        AssertionError, 'Length of `inputs` and `expected_types` must match'):
+        AssertionError,
+        _get_err_regex('Length of `inputs` and `expected_types` must match')):
       asserts.assert_type(array, wrong_type)
 
   def test_type_should_fail_unsupported_dtype(self):
@@ -545,7 +575,8 @@ class TypeAssertTest(parameterized.TestCase):
     an_int = 2
     a_np_float = np.asarray([3., 4.])
     a_jax_int = jnp.asarray([5, 6])
-    with self.assertRaisesRegex(AssertionError, 'unsupported dtype'):
+    with self.assertRaisesRegex(AssertionError,
+                                _get_err_regex('unsupported dtype')):
       asserts.assert_type([a_float, an_int, a_np_float, a_jax_int],
                           [np.complex, np.complex, float, int])
 
@@ -563,33 +594,36 @@ class AxisDimensionAssertionsTest(parameterized.TestCase):
     for i in range(-tensor.ndim, tensor.ndim):
       s = tensor.shape[i]
       with self.assertRaisesRegex(
-          AssertionError, 'Expected tensor to have dimension'):
-        asserts.assert_axis_dimension(tensor, axis=i, expected=s+1)
+          AssertionError, _get_err_regex('Expected tensor to have dimension')):
+        asserts.assert_axis_dimension(tensor, axis=i, expected=s + 1)
 
   def test_assert_axis_dimension_axis_invalid(self):
     tensor = jnp.ones((3, 2))
     for i in (2, -3):
-      with self.assertRaisesRegex(AssertionError, 'not available'):
+      with self.assertRaisesRegex(AssertionError,
+                                  _get_err_regex('not available')):
         asserts.assert_axis_dimension(tensor, axis=i, expected=1)
 
   def test_assert_axis_dimension_gt_pass(self):
     tensor = jnp.ones((3, 2, 7, 2))
     for i in range(-tensor.ndim, tensor.ndim):
       s = tensor.shape[i]
-      asserts.assert_axis_dimension_gt(tensor, axis=i, val=s-1)
+      asserts.assert_axis_dimension_gt(tensor, axis=i, val=s - 1)
 
   def test_assert_axis_dimension_gt_fail(self):
     tensor = jnp.ones((3, 2, 7, 2))
     for i in range(-tensor.ndim, tensor.ndim):
       s = tensor.shape[i]
       with self.assertRaisesRegex(
-          AssertionError, 'Expected tensor to have dimension greater than'):
+          AssertionError,
+          _get_err_regex('Expected tensor to have dimension greater than')):
         asserts.assert_axis_dimension_gt(tensor, axis=i, val=s)
 
   def test_assert_axis_dimension_gt_axis_invalid(self):
     tensor = jnp.ones((3, 2))
     for i in (2, -3):
-      with self.assertRaisesRegex(AssertionError, 'not available'):
+      with self.assertRaisesRegex(AssertionError,
+                                  _get_err_regex('not available')):
         asserts.assert_axis_dimension_gt(tensor, axis=i, val=0)
 
 
@@ -607,28 +641,34 @@ class TreeAssertionsTest(parameterized.TestCase):
     tree6 = dict(x=1, y=2, z=3, n=None)
 
     with self.assertRaisesRegex(
-        AssertionError, 'Error in tree structs equality check.*trees 0 and 1'):
+        AssertionError,
+        _get_err_regex('Error in tree structs equality check.*trees 0 and 1')):
       assert_fn(tree1, tree5)
 
     with self.assertRaisesRegex(
-        AssertionError, 'Error in tree structs equality check.*trees 0 and 1'):
+        AssertionError,
+        _get_err_regex('Error in tree structs equality check.*trees 0 and 1')):
       assert_fn(tree1, tree3)
 
     with self.assertRaisesRegex(
-        AssertionError, 'Error in tree structs equality check.*trees 0 and 2'):
+        AssertionError,
+        _get_err_regex('Error in tree structs equality check.*trees 0 and 2')):
       assert_fn([], [], tree1)
 
     with self.assertRaisesRegex(
-        AssertionError, 'Error in tree structs equality check.*trees 0 and 3'):
+        AssertionError,
+        _get_err_regex('Error in tree structs equality check.*trees 0 and 3')):
       assert_fn(tree2, tree1, tree2, tree3, tree1)
 
     with self.assertRaisesRegex(
-        AssertionError, 'Error in tree structs equality check.*trees 0 and 2'):
+        AssertionError,
+        _get_err_regex('Error in tree structs equality check.*trees 0 and 2')):
       assert_fn(tree2, tree1, tree4)
 
     # Test `None`s.
     with self.assertRaisesRegex(
-        AssertionError, 'Error in tree structs equality check.*trees 0 and 1'):
+        AssertionError,
+        _get_err_regex('Error in tree structs equality check.*trees 0 and 1')):
       assert_fn(tree5, tree6)
 
   def test_tree_all_finite_passes_finite(self):
@@ -640,96 +680,104 @@ class TreeAssertionsTest(parameterized.TestCase):
         'finite_var': jnp.ones((3,)),
         'inf_var': jnp.array([0.0, jnp.inf]),
     }
-    with self.assertRaisesRegex(AssertionError,
-                                'Tree contains non-finite value'):
+    with self.assertRaisesRegex(
+        AssertionError, _get_err_regex('Tree contains non-finite value')):
       asserts.assert_tree_all_finite(inf_tree)
 
-  def test_assert_tree_all_close_passes_same_tree(self):
+  def test_assert_trees_all_close_passes_same_tree(self):
     tree1 = {
         'a': [jnp.zeros((1,))],
         'b': ([0], (0,), 0),
     }
-    asserts.assert_tree_all_close(tree1, tree1)
+    asserts.assert_trees_all_close(tree1, tree1)
 
-  def test_assert_tree_all_close_passes_values_equal(self):
+  def test_assert_trees_all_close_passes_values_equal(self):
     tree1 = (jnp.array([0.0, 0.0]),)
     tree2 = (jnp.array([0.0, 0.0]),)
-    asserts.assert_tree_all_close(tree1, tree2)
+    asserts.assert_trees_all_close(tree1, tree2)
 
-  def test_assert_tree_all_close_passes_values_close(self):
+  def test_assert_trees_all_close_passes_values_close(self):
     tree1 = (jnp.array([1.0, 1.0]),)
     tree2 = (jnp.array([1.0, 1.0 + 1e-9]),)
-    asserts.assert_tree_all_close(tree1, tree2)
+    asserts.assert_trees_all_close(tree1, tree2)
 
-  def test_assert_tree_all_close_nones(self):
+  def test_assert_trees_all_close_nones(self):
     tree = {'a': [jnp.zeros((1,))], 'b': None}
-    asserts.assert_tree_all_close(tree, tree, ignore_nones=True)
-    with self.assertRaisesRegex(AssertionError, '`None` detected'):
-      asserts.assert_tree_all_close(tree, tree, ignore_nones=False)
+    asserts.assert_trees_all_close(tree, tree, ignore_nones=True)
+    with self.assertRaisesRegex(AssertionError,
+                                _get_err_regex('`None` detected')):
+      asserts.assert_trees_all_close(tree, tree, ignore_nones=False)
 
-  def test_assert_tree_all_equal_shapes_nones(self):
+  def test_assert_trees_all_equal_shapes_nones(self):
     tree = {'a': [jnp.zeros((1,))], 'b': None}
-    asserts.assert_tree_all_equal_shapes(tree, tree, ignore_nones=True)
-    with self.assertRaisesRegex(AssertionError, '`None` detected'):
-      asserts.assert_tree_all_equal_shapes(tree, tree, ignore_nones=False)
+    asserts.assert_trees_all_equal_shapes(tree, tree, ignore_nones=True)
+    with self.assertRaisesRegex(AssertionError,
+                                _get_err_regex('`None` detected')):
+      asserts.assert_trees_all_equal_shapes(tree, tree, ignore_nones=False)
 
   def test_assert_tree_no_nones(self):
     tree_ok = {'a': [jnp.zeros((1,))], 'b': 1}
     asserts.assert_tree_no_nones(tree_ok)
 
     tree_with_none = {'a': [jnp.zeros((1,))], 'b': None}
-    with self.assertRaisesRegex(AssertionError, '`None` detected'):
+    with self.assertRaisesRegex(AssertionError,
+                                _get_err_regex('`None` detected')):
       asserts.assert_tree_no_nones(tree_with_none)
 
     # Check `None`.
-    with self.assertRaisesRegex(AssertionError, '`None` detected'):
+    with self.assertRaisesRegex(AssertionError,
+                                _get_err_regex('`None` detected')):
       asserts.assert_tree_no_nones(None)
 
-  def test_assert_tree_all_close_fails_different_structure(self):
-    self._assert_tree_structs_validation(asserts.assert_tree_all_close)
+  def test_assert_trees_all_close_fails_different_structure(self):
+    self._assert_tree_structs_validation(asserts.assert_trees_all_close)
 
-  def test_assert_tree_all_close_fails_values_differ(self):
+  def test_assert_trees_all_close_fails_values_differ(self):
     tree1 = (jnp.array([0.0, 2.0]))
     tree2 = (jnp.array([0.0, 2.1]))
-    asserts.assert_tree_all_close(tree1, tree2, atol=0.1)
-    with self.assertRaisesRegex(AssertionError,
-                                'Values not approximately equal'):
-      asserts.assert_tree_all_close(tree1, tree2, atol=0.01)
+    asserts.assert_trees_all_close(tree1, tree2, atol=0.1)
+    with self.assertRaisesRegex(
+        AssertionError, _get_err_regex('Values not approximately equal')):
+      asserts.assert_trees_all_close(tree1, tree2, atol=0.01)
 
-    asserts.assert_tree_all_close(tree1, tree2, rtol=0.1)
-    with self.assertRaisesRegex(AssertionError,
-                                'Values not approximately equal'):
-      asserts.assert_tree_all_close(tree1, tree2, rtol=0.01)
+    asserts.assert_trees_all_close(tree1, tree2, rtol=0.1)
+    with self.assertRaisesRegex(
+        AssertionError, _get_err_regex('Values not approximately equal')):
+      asserts.assert_trees_all_close(tree1, tree2, rtol=0.01)
 
-  def test_assert_tree_all_equal_shapes(self):
+  def test_assert_trees_all_equal_shapes(self):
     get_val = lambda s: jnp.zeros([s])
     tree1 = dict(a1=get_val(3), d=dict(a2=get_val(4), a3=get_val(5)))
     tree2 = dict(a1=get_val(3), d=dict(a2=get_val(4), a3=get_val(5)))
     tree3 = dict(a1=get_val(3), d=dict(a2=get_val(7), a3=get_val(5)))
 
-    self._assert_tree_structs_validation(asserts.assert_tree_all_equal_shapes)
-    asserts.assert_tree_all_equal_shapes(tree1, tree1)
-    asserts.assert_tree_all_equal_shapes(tree2, tree1)
+    self._assert_tree_structs_validation(asserts.assert_trees_all_equal_shapes)
+    asserts.assert_trees_all_equal_shapes(tree1, tree1)
+    asserts.assert_trees_all_equal_shapes(tree2, tree1)
 
     with self.assertRaisesRegex(
         AssertionError,
-        r'Trees 0 and 1 differ in leaves \'d/a2\': shapes: \(4,\) != \(7,\).'):
-      asserts.assert_tree_all_equal_shapes(tree1, tree3)
+        _get_err_regex(
+            r'Trees 0 and 1 differ in leaves \'d/a2\': shapes: \(4,\) != \(7,\)'
+        )):
+      asserts.assert_trees_all_equal_shapes(tree1, tree3)
 
     with self.assertRaisesRegex(
         AssertionError,
-        r'Trees 0 and 3 differ in leaves \'d/a2\': shapes: \(4,\) != \(7,\).'):
-      asserts.assert_tree_all_equal_shapes(tree1, tree2, tree2, tree3, tree1)
+        _get_err_regex(
+            r'Trees 0 and 3 differ in leaves \'d/a2\': shapes: \(4,\) != \(7,\)'
+        )):
+      asserts.assert_trees_all_equal_shapes(tree1, tree2, tree2, tree3, tree1)
 
-  def test_assert_tree_all_equal_structs(self):
+  def test_assert_trees_all_equal_structs(self):
     get_val = lambda: jnp.zeros([3])
     tree1 = [[get_val(), get_val()], get_val()]
     tree2 = [[get_val(), get_val()], get_val()]
     tree3 = [get_val(), [get_val(), get_val()]]
 
-    asserts.assert_tree_all_equal_structs(tree1, tree2, tree2, tree1)
-    asserts.assert_tree_all_equal_structs(tree3, tree3)
-    self._assert_tree_structs_validation(asserts.assert_tree_all_equal_structs)
+    asserts.assert_trees_all_equal_structs(tree1, tree2, tree2, tree1)
+    asserts.assert_trees_all_equal_structs(tree3, tree3)
+    self._assert_tree_structs_validation(asserts.assert_trees_all_equal_structs)
 
   def test_assert_tree_shape_prefix(self):
     tree = {'x': {'y': np.zeros([3, 2])}, 'z': np.zeros([3, 2, 1])}
@@ -739,19 +787,21 @@ class TreeAssertionsTest(parameterized.TestCase):
 
     with self.assertRaisesRegex(
         AssertionError,
-        r'Tree leaf \'x/y\' .* diffent from expected: \(3, 2\) != \(3, 2, 1\)'
-    ):
+        _get_err_regex(
+            r'Tree leaf \'x/y\'.*diffent from expected: \(3, 2\) != \(3, 2, 1\)'
+        )):
       asserts.assert_tree_shape_prefix(tree, (3, 2, 1))
 
   def test_assert_tree_shape_prefix_none(self):
     tree = {'x': np.zeros([3]), 'n': None}
     asserts.assert_tree_shape_prefix(tree, (3,), ignore_nones=True)
 
-    with self.assertRaisesRegex(AssertionError, '`None` detected'):
+    with self.assertRaisesRegex(AssertionError,
+                                _get_err_regex('`None` detected')):
       asserts.assert_tree_shape_prefix(tree, (3,), ignore_nones=False)
 
 
-class NumDevicesAssertTest(parameterized.TestCase):
+class DevicesAssertTest(parameterized.TestCase):
 
   def _device_count(self, backend):
     try:
@@ -765,7 +815,8 @@ class NumDevicesAssertTest(parameterized.TestCase):
     if n > 0:
       asserts.assert_devices_available(
           n - 1, devtype, backend=devtype, not_less_than=True)
-      with self.assertRaisesRegex(AssertionError, f'Only {n} < {n + 1}'):
+      with self.assertRaisesRegex(AssertionError,
+                                  _get_err_regex(f'Only {n} < {n + 1}')):
         asserts.assert_devices_available(
             n + 1, devtype, backend=devtype, not_less_than=True)
     else:
@@ -783,12 +834,15 @@ class NumDevicesAssertTest(parameterized.TestCase):
     if n_gpu:
       asserts.assert_gpu_available()
     else:
-      with self.assertRaisesRegex(AssertionError, 'No 2 GPUs available'):
+      with self.assertRaisesRegex(AssertionError,
+                                  _get_err_regex('No 2 GPUs available')):
         asserts.assert_devices_available(2, 'gpu')
-      with self.assertRaisesRegex(AssertionError, 'No GPU devices available'):
+      with self.assertRaisesRegex(AssertionError,
+                                  _get_err_regex('No GPU devices available')):
         asserts.assert_gpu_available()
 
-    with self.assertRaisesRegex(AssertionError, 'No 2 GPUs available'):
+    with self.assertRaisesRegex(AssertionError,
+                                _get_err_regex('No 2 GPUs available')):
       asserts.assert_devices_available(2, 'gpu', backend='cpu')
 
   def test_cpu_assert(self):
@@ -801,11 +855,14 @@ class NumDevicesAssertTest(parameterized.TestCase):
     if n_tpu:
       asserts.assert_tpu_available()
     else:
-      with self.assertRaisesRegex(AssertionError, 'No 3 TPUs available'):
+      with self.assertRaisesRegex(AssertionError,
+                                  _get_err_regex('No 3 TPUs available')):
         asserts.assert_devices_available(3, 'tpu')
-      with self.assertRaisesRegex(AssertionError, 'No TPU devices available'):
+      with self.assertRaisesRegex(AssertionError,
+                                  _get_err_regex('No TPU devices available')):
         asserts.assert_tpu_available()
-    with self.assertRaisesRegex(AssertionError, 'No 3 TPUs available'):
+    with self.assertRaisesRegex(AssertionError,
+                                _get_err_regex('No 3 TPUs available')):
       asserts.assert_devices_available(3, 'tpu', backend='cpu')
 
 
@@ -889,8 +946,8 @@ class EqualAssertionsTest(parameterized.TestCase):
   def test_assert_equal_pass_on_arrays(self):
     # Not using named_parameters, becase JAX cannot be used before app.run().
     asserts.assert_equal(jnp.ones([]), np.ones([]))
-    asserts.assert_equal(jnp.ones([], dtype=jnp.int32),
-                         np.ones([], dtype=np.float64))
+    asserts.assert_equal(
+        jnp.ones([], dtype=jnp.int32), np.ones([], dtype=np.float64))
 
   @parameterized.named_parameters(
       ('dtypes', jnp.int32, jnp.float32),
